EqualsStrategy

Trait EqualsStrategy 

pub trait EqualsStrategy<A, B> {
    // Required method
    fn equals(&self, a: &A, b: &B) -> bool;
}
A strategy for “do these two geometries describe the same point set?”.

Mirrors boost::geometry::equals(g1, g2) from boost/geometry/algorithms/equals.hpp.

Required Methods

fn equals(&self, a: &A, b: &B) -> bool

true iff a and b describe the same point set.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<A, B, P> EqualsStrategy<A, B> for EqPolygonPolygon
where A: PolygonTrait<Point = P>, B: PolygonTrait<Point = P, Ring = A::Ring>, P: PointTrait, P::Scalar: CoordinateScalar, <P::Cs as CoordinateSystem>::Family: SameAs<CartesianFamily>,

Source

impl<A, B, P> EqualsStrategy<A, B> for EqSegmentSegment

Source

impl<A, B> EqualsStrategy<A, B> for EqPointPoint