pub enum MeridianSegmentKind {
NonMeridian,
NotCrossingPole,
CrossingPole,
}Expand description
Classification of a spheroidal segment relative to a meridian.
Variants
NonMeridian
The endpoints do not define a meridian segment.
NotCrossingPole
Both endpoints use the same meridian and the path avoids a pole.
CrossingPole
The longitudes differ by π and the meridian path crosses a pole.