pub trait TransformStrategy<P: Point> {
type Output: PointMut + Default;
// Required method
fn transform(&self, src: &P) -> Self::Output;
}Expand description
A function from one Point to another, used by
transform.
The output may have a different scalar type or coordinate system
than the input. Self::Output must be
PointMut + Default because the strategy builds it via
Default + set::<D>.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".